# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

%define uname   SPIRV-Headers
%define vulkanver 1.4.309.0
%define vulkansdk vulkan-sdk-%{vulkanver}

%define rel 4

Name:           spirv-headers
# Check include/spirv/unified1/spirv.core.grammar.json for the proper version number.
Version:        1.6.4
Release:        %mkrel %{rel}.sdk%{vulkanver}
Summary:        Header files from the SPIR-V registry
Group:          Development/C
License:        MIT
URL:            https://github.com/KhronosGroup/SPIRV-Headers
Source0:        https://github.com/KhronosGroup/SPIRV-Headers/archive/%{vulkansdk}.tar.gz

BuildArch:      noarch
BuildRequires:  cmake

Provides:	spirv-headers-devel = %{version}-%{release}

%description
Header files from the SPIR-V registry. This includes:

* Header files for various languages.
* JSON files describing the grammar for the SPIR-V core instruction
  set, and for the GLSL.std.450 extended instruction set.
* The XML registry file.
* CMake config files to include this in other CMake projects.

%prep
%autosetup -p1 -n %{uname}-%{vulkansdk}

# Fix version
sed -i -e '/project/s/\(VERSION\)\s\+[0-9]\+\(\.[0-9]\+\)\+/\1 %{version}/' CMakeLists.txt

%build
%cmake -DSPIRV_HEADERS_SKIP_EXAMPLES=ON
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license LICENSE
%{_datadir}/cmake/%{uname}/
%{_datadir}/pkgconfig/%{uname}.pc
%{_includedir}/spirv/


%changelog
* Mon Apr 21 2025 daviddavid <daviddavid> 1.6.4-4.sdk1.4.309.0.mga10
+ Revision: 2177883
- update to 1.4.309.0 SDK

* Wed Jan 22 2025 daviddavid <daviddavid> 1.6.4-3.sdk1.4.304.0.mga10
+ Revision: 2140469
- update to 1.4.304.0 SDK

* Tue Nov 12 2024 wally <wally> 1.6.4-2.sdk1.3.296.0.mga10
+ Revision: 2114587
- fix version in CMake files
- provide spirv-headers-devel

* Tue Nov 12 2024 wally <wally> 1.6.4-1.sdk1.3.296.0.mga10
+ Revision: 2114580
- SDK 1.3.296.0

* Tue Aug 20 2024 daviddavid <daviddavid> 1.6.1-4.sdk1.3.290.0.1.mga10
+ Revision: 2087101
- include the vulkan version into the release tag

* Tue Aug 20 2024 daviddavid <daviddavid> 1.6.1-3.mga10
+ Revision: 2087078
- update to 1.3.290.0 SDK

* Tue Feb 27 2024 wally <wally> 1.6.1-2.mga10
+ Revision: 2044657
- Vulkan SDK 1.3.275.0

* Mon Nov 14 2022 akien <akien> 1.6.1-1.mga9
+ Revision: 1907184
- Version 1.6.1, Vulkan SDK 1.3.231.1

* Thu Mar 24 2022 umeabot <umeabot> 1.5.5-3.mga9
+ Revision: 1825151
- Mageia 9 Mass Rebuild

* Mon Mar 07 2022 akien <akien> 1.5.5-2.mga9
+ Revision: 1789592
- Build with CMake buildsystem, package CMake files

* Mon Mar 07 2022 akien <akien> 1.5.5-1.mga9
+ Revision: 1789518
- Version 1.5.5, Vulkan SDK 1.3.204.1

* Wed Dec 30 2020 akien <akien> 1.5.4-1.f027d53.mga8
+ Revision: 1666456
- Commit f027d53, matches requirements for Vulkan SDK 1.2.162.0

* Mon Oct 12 2020 akien <akien> 1.5.3-1.060627f.mga8
+ Revision: 1633737
- Commit 060627f, matches requirements for Vulkan SDK 1.2.154.0

* Mon Feb 17 2020 akien <akien> 1.5.1-3.204cd13.mga8
+ Revision: 1536915
- Commit 204cd13, matching requirements for Vulkan SDK 1.2.131.2

* Sun Feb 16 2020 umeabot <umeabot> 1.5.1-2.38cafab.mga8
+ Revision: 1533899
- Mageia 8 Mass Rebuild

* Wed Sep 25 2019 akien <akien> 1.5.1-1.38cafab.mga8
+ Revision: 1445835
- Commit 38cafab, matching requirements for Vulkan SDK 1.1.121.0

* Thu Apr 18 2019 akien <akien> 1.3.7-3.2434b89.mga7
+ Revision: 1393152
- Commit 2434b893, matching requirements from Vulkan SDK 1.1.106.0

* Wed Mar 27 2019 akien <akien> 1.3.7-2.3beb2a0.mga7
+ Revision: 1380634
- Update to git 3beb2a0 required by glslang@5432f0d required by Vulkan SDK 1.1.101.1

* Tue Mar 26 2019 akien <akien> 1.3.7-1.mga7
+ Revision: 1380455
- Version 1.3.7

* Mon Dec 10 2018 akien <akien> 1.2-0.20181130.1.mga7
+ Revision: 1339715
- Adapt spec file to Mageia policies, simplify
- import spirv-headers from Fedora Rawhide


* Sat Oct 20 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.9.20180703.gitff684ff
- Revert last commit

* Sat Oct 20 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.8.20180919.gitd5b2e12
- Update for SPIRV-Tools-2018.5

* Mon Jul 23 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.7.20180703.gitff684ff
- Update for SPIRV-Tools-2018.4

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.2-0.6.20180405.git12f8de9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Apr 24 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.5.20180405.git12f8de9
- Update for vulkan 1.0.73.0

* Fri Feb 09 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.4.20180201.gitce30920
- Update for vulkan 1.0.68.0

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.2-0.3.20171015.git0610978
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 22 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.2.20171015.git0610978
- fix rpmlint error

* Thu Jul 13 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.2-0.1.20171015.git0610978
- First build

